@@ -3,10 +3,10 @@ This module generates a report of the network simulation model
 using LaTeX.
 """
 import os, sys, commands, string, time, matplotlib, codecs
-matplotlib.use("Agg")
+#matplotlib.use("Agg")
 
-from pylab import *
-from matplotlib.mlab import *
+#from pylab import *
+#from matplotlib.mlab import *
 
 header =r"""
 \documentclass[a4paper,10pt]{report}
